Module: KeyPath::HashDeepMerge
- Included in:
- Hash
- Defined in:
- lib/key_path/hash/deep_merge.rb
Instance Method Summary collapse
-
#deep_merge(other_hash) ⇒ Object
Recursive version of Hash#merge.
-
#deep_merge!(other_hash) ⇒ Object
Recursive version of Hash#merge!.
Instance Method Details
#deep_merge(other_hash) ⇒ Object
Recursive version of Hash#merge
Compared with Hash#merge!, this method supports nested hashes. When both hsh and other_hash contains an entry with the same key, it merges and returns the values from both arrays.
Compared with Hash#merge, this method provides a different approch for merging nasted hashes. If the value of a given key is an Hash and both other_hash abd +hsh includes the same key, the value is merged instead replaced with other_hash value.
h1 = {"a" => 100, "b" => 200, "c" => {"c1" => 12, "c2" => 14}}
h2 = {"b" => 254, "c" => 300, "c" => {"c1" => 16, "c3" => 94}}
h1.rmerge(h2) #=> {"a" => 100, "b" => 254, "c" => {"c1" => 16, "c2" => 14, "c3" => 94}}
Simply using Hash#merge would return
h1.merge(h2) #=> {"a" => 100, "b" = >254, "c" => {"c1" => 16, "c3" => 94}}
62 63 64 65 66 67 |
# File 'lib/key_path/hash/deep_merge.rb', line 62 def deep_merge(other_hash) r = {} merge(other_hash) do |key, oldval, newval| r[key] = oldval.class == self.class ? oldval.deep_merge(newval) : newval end end |
#deep_merge!(other_hash) ⇒ Object
Recursive version of Hash#merge!
Adds the contents of other_hash to hsh, merging entries in hsh with duplicate keys with those from other_hash.
Compared with Hash#merge!, this method supports nested hashes. When both hsh and other_hash contains an entry with the same key, it merges and returns the values from both arrays.
h1 = {"a" => 100, "b" => 200, "c" => {"c1" => 12, "c2" => 14}}
h2 = {"b" => 254, "c" => 300, "c" => {"c1" => 16, "c3" => 94}}
h1.rmerge!(h2) #=> {"a" => 100, "b" => 254, "c" => {"c1" => 16, "c2" => 14, "c3" => 94}}
Simply using Hash#merge! would return
h1.merge!(h2) #=> {"a" => 100, "b" = >254, "c" => {"c1" => 16, "c3" => 94}}
35 36 37 38 39 |
# File 'lib/key_path/hash/deep_merge.rb', line 35 def deep_merge!(other_hash) merge!(other_hash) do |key, oldval, newval| oldval.class == self.class ? oldval.deep_merge!(newval) : newval end end |